#========================================================================================
# package      DE_EPAGES::AppStore::Hooks::Shop
# state        public
# description  Hook functions of the cartridge AppStore.
#========================================================================================
package DE_EPAGES::AppStore::Hooks::Shop;

use strict;
use DE_EPAGES::AppStore::API::Shop qw (
    CreateUnityScriptTagsApp
    DeleteUnityScriptTagsApp
);
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::Log qw ( LogError );

#========================================================================================
# function     OnBeforeCreateUnityShop
#----------------------------------------------------------------------------------------
# syntax       OnBeforeCreateUnityShop( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook API_OnBeforeCreateUnityShop.
#               Installs the UnityScriptTagsApp upon creation of a Unity shop
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Object - the current Shop - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnBeforeCreateUnityShop {
    my ($hParams) = @_;
    my $Shop = $hParams->{'Object'};

    CreateUnityScriptTagsApp($Shop);
}

#========================================================================================
# function     OnDeleteShop
#----------------------------------------------------------------------------------------
# syntax       OnDeleteShop( $hParams );
#----------------------------------------------------------------------------------------
# description  Triggered by the hook OBJ_DeleteShop.
#               Deletes the UnityScriptTagsApp upon deletion of a Unity shop
#----------------------------------------------------------------------------------------
# input        $hParams | hook parameter
#               <ul>
#                   <li>Object - the current Shop - object
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeleteShop {
    my ($hParams) = @_;
    my $Shop = $hParams->{'Object'};

    return unless $Shop->featureMaxValue('Unity');

    eval {
        DeleteUnityScriptTagsApp($Shop);
    };
    LogError(GetError()) if ExistsError();
}

1;
