#========================================================================================
# package      DE_EPAGES::DHLIntraship::API::SOAP::PackstationRequest
# state        public
# description  Request builder for getPackstationsByAddress DHL Intraship webservice method
#========================================================================================
package DE_EPAGES::DHLIntraship::API::SOAP::PackstationRequest;

use DE_EPAGES::DHLIntraship::API::Constants qw ($GERMAN_LOCALE);

use strict;

sub new {
    my $class = shift;
    my ($Servlet) = @_;

    my $self  = bless {
        'getPackstationsByAddress'  => \&_setPackstationsByAddress
    }, $class;

    return $self;
}

#========================================================================================
# function     assemble
# state        public_private
#----------------------------------------------------------------------------------------
# syntax       assemble( $operation, $aShippingLabels );
#----------------------------------------------------------------------------------------
# description  Create the hash with all necessary values for the request
#----------------------------------------------------------------------------------------
# input        $operation | Operation name | String
# input        $Servlet | SF servlet | object
# return       $hRequest | Data structure to perform the request | refhash
#========================================================================================
sub assemble {
    my $self = shift;
    my ($Operation, $Servlet) = @_;
    return unless (defined ($self->{$Operation}));

    return $self->{$Operation}($self, $Servlet);
}

#----------------------------------------------------------------------------------------
sub _setPackstationsByAddress {
    my $self = shift;
    my ($Servlet) = @_;

    my $hServletParams = $Servlet->params();

    my $hRequest = {
        'key' => '',
        'address' => {
            'street'        => $hServletParams->{'Street'},
            'streetNo'      => $hServletParams->{'StreetNo'},
            'zip'           => $hServletParams->{'ZipCode'},
            'city'          => $hServletParams->{'City'},
            'countryCode'   => $GERMAN_LOCALE,
        },
    };

    return $hRequest;

}

1;