#========================================================================================
# package      DE_EPAGES::DHLIntraship::UI::JSONServiceOptions
# state        private
#========================================================================================
package DE_EPAGES::DHLIntraship::UI::JSONServiceOptions;
use base DE_EPAGES::Presentation::UI::JSON;
use DE_EPAGES::Core::API::Error qw ( Error ExistsError GetError );
use DE_EPAGES::Core::API::Log qw ( LogError );
use DE_EPAGES::DHLIntraship::API::Constants qw (
    $EKP_LENGHT
    $PRODUCTCODE_LENGHT
    %MAPPING_PRODUCTCODE_FULLPRODUCTNAME
);
use DE_EPAGES::DHLIntraship::API::SOAP::PackstationRequest;
use DE_EPAGES::DHLIntraship::API::SOAP::PackstationResponse;
use DE_EPAGES::DHLIntraship::API::SOAP::WebServiceClient;
use DE_EPAGES::DHLIntraship::API::Tools;

use strict;

#========================================================================================
# function     JSONViewPackstations
# state        public
#----------------------------------------------------------------------------------------
# syntax       JSONViewPackstations( $Servlet );
#----------------------------------------------------------------------------------------
# description  Ajax endpoint to get the packstations from DHL Intraship
#----------------------------------------------------------------------------------------
# input        $Servlet | ShippingFulfillmentMethod object from SF | object
#========================================================================================
sub JSONViewPackstations {
    my $self = shift;
    my ($Servlet) = @_;

    my $ShippingFulfillmentMethod = $Servlet->object();

    my $MethodName = (caller(0))[3];
    DE_EPAGES::DHLIntraship::API::Tools->LogShopContext(
            $ShippingFulfillmentMethod,
            $MethodName,
            sub {
                my $PackstationRequestBuilder = DE_EPAGES::DHLIntraship::API::SOAP::PackstationRequest->new();
                my $PackstationResponseParser = DE_EPAGES::DHLIntraship::API::SOAP::PackstationResponse->new();
                my $DHLWSClient = DE_EPAGES::DHLIntraship::API::SOAP::WebServiceClient->new(
                        $PackstationRequestBuilder,
                        $PackstationResponseParser,
                        $ShippingFulfillmentMethod->get('IsInTestMode')
                );

                my $aPackstations;
                eval { 
                    $aPackstations = $DHLWSClient->getPackstationsByAddress($Servlet);
                };
                if (ExistsError()) {
                    my $Error = GetError();
                    LogError($Error);
                    Error('PackstationServiceError');
                }

                $self->writeContentOutput($aPackstations);
            }
    );

    return;
}

1;