#========================================================================================
# package      DE_EPAGES::Ogone::t::Ogone
# base         DE_EPAGES::Shop::API::Test
# state        private
#========================================================================================
package DE_EPAGES::Ogone::t::PaymentMethodOgone;
use base DE_EPAGES::Shop::API::Test;
use strict;

## no critic (ProhibitMagicNumbers ProhibitLongLines)
use Data::Dumper;
use DE_EPAGES::Ogone::API::Object::PaymentMethodOgone;
use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath );
use DE_EPAGES::Payment::API::Table::ShippingPaymentMap qw ( InsertShippingPaymentMap );
use DE_EPAGES::Shop::API::Constants qw ( TAX_MODEL_GROSS );
use Test::Exception;
use Test::More;

sub init() {
    my $self = shift;
    $self->SUPER::init();

    $self->shop->featureMaxValue('PaymentMethods', 10);
    $self->shop->featureMaxValue('Ogone', 1);
    $self->shop->featureMaxValue('Basket', 1);
    $self->shop->featureMaxValue('Products', 1);
    $self->shop->featureMaxValue('ShippingMethods', 1);

    LoadObjectByPath('/PaymentTypes/Free')->newPaymentMethod($self->shop, {
        IsActivated => 1,
        IsDefault   => 1,
    });

    LoadObjectByPath('/ShippingTypes/Free')->newShippingMethod($self->shop, {
        IsActivated => 1,
        IsDefault   => 1,
    });

    # defaults to a valid region for Ogone
    $self->shop->set({
        CurrencyID => 'EUR',
        LocaleID  => 'de_DE',
        OrderProcess => 1,
    });

    my $ProductFolder = $self->shop->folder('Products');
    my $Product = $ProductFolder->insertChild('Product', {
        Alias => 'TestProduct',
        Shop  => $self->shop,
    });
    $Product->setListPrice('EUR', 0, 1);

}

sub test {
    my $self = shift;
    SKIP: {
        $self->testPaymentMethod();
    }
    done_testing;
}

sub testPaymentMethod {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentType = LoadObjectByPath('/PaymentTypes/Ogone');
    my $PaymentMethod = $PaymentType->newPaymentMethod($self->shop, {
        IsActivated => 1,
        IsDefault   => 0,
        Alias       => 'OgonePaymentTest'
    });

    InsertShippingPaymentMap({
        ShippingMethodID => $_->id,
        PaymentMethodID => $PaymentMethod->id
    }) foreach (@{$self->shop->folder('ShippingMethods')->children});

    # usableAtStorefront
    is($PaymentMethod->get('IsActivated'), 1, $SubTestName.' payment is activated');

    ok(! $PaymentMethod->usableAtStorefront({CurrencyID => 'EUR', TaxModel => TAX_MODEL_GROSS }), $SubTestName.' Not usable at Storefront because no MerchantPasswordTest');

    #  usableAtStorefront - set password undef
    my $hPaymentMethodInfo = {
        'MerchantNameTest'     => 4,
        'MerchantPasswordTest' => undef,
        'PassphraseTest'       => 6,
    };
    $PaymentMethod->set($hPaymentMethodInfo);

    is($PaymentMethod->get('IsActivated'), 1, $SubTestName.' payment is still activated');
    ok(! $PaymentMethod->usableAtStorefront({CurrencyID => 'EUR', TaxModel => TAX_MODEL_GROSS }), $SubTestName.' Not usable at Storefront because MerchantPasswordTest is undef');

    #  usableAtStorefront - set valid password
    $PaymentMethod->set({'MerchantPasswordTest'=> 'somePass'});
    ok($PaymentMethod->usableAtStorefront({CurrencyID => 'EUR', TaxModel => TAX_MODEL_GROSS }), $SubTestName.' Is usable at Storefront ');


}

__PACKAGE__->runScript;
