#========================================================================================
# package      package DE_EPAGES::Order::API::JWT;
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides the JsonWebToken for the Order.
#========================================================================================
package DE_EPAGES::Order::API::JWT;
use base Exporter;
use strict;

use DE_EPAGES::Core::API::PerlTools qw( CreateJsonWebToken );
use DE_EPAGES::Database::API::Config qw ( DatabaseConnectionData );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );
use DE_EPAGES::Shop::API::Constants qw ( EDITOR_JWT_LIFETIME );

our @EXPORT_OK = qw( CreateOrderJsonWebToken AddOrderTokenToURL );


#========================================================================================
# function     CreateOrderJsonWebToken
# state        public
#----------------------------------------------------------------------------------------
# syntax       CreateOrderJsonWebToken($Lifetime, $Shop, $Scope);
#----------------------------------------------------------------------------------------
# description  Returns a newly created JSON web token with the order guid as subject
#               and the secret taken from the "jwtsecret" key-value pair of the
#               respective store conf.
#               See <function DE_EPAGES::Core::API::PerlTools::CreateJsonWebToken>.
#----------------------------------------------------------------------------------------
# input        $Lifetime | the token's lifetime in seconds| integer
# input        $Order | order  | object
# input        $Scope | the token's scope (e.g. editor, order or provisioning)| string
# return       $JWT | encoded JSON web token | string
#========================================================================================
sub CreateOrderJsonWebToken {
    my ($Lifetime, $Order, $Scope) = @_;

    return CreateJsonWebToken($Lifetime, $Order->get('GUID'), $Scope,
        'http://epages.com/epages6', 'http://epages.com/unity',
        DatabaseConnectionData(LoadRootObject->get('StoreName'))->{'jwtsecret'});
}

#========================================================================================
# function     AddOrderTokenToURL
# state        public
#----------------------------------------------------------------------------------------
# syntax       AddOrderTokenToURL($Servlet, $URL);
#----------------------------------------------------------------------------------------
# description  Creates a new JWT with the order scope and adds it to the given URL
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet  | object
# input        $URL | cureent URL | string
# return       $URL | URL with added JWT | string
#========================================================================================
sub AddOrderTokenToURL {
    my ($Servlet, $URL) = @_;

    # create a JWT for viewing the oder with a lifetime of 3 minutes
    # add token to the end of the URL
    my $Delimiter = $URL =~ /\?/ ? '&' : '?';
    $URL .= $Delimiter . "viewtkn=" . CreateOrderJsonWebToken(EDITOR_JWT_LIFETIME, $Servlet->object, 'order');

    return $URL;
}

1;
