#========================================================================================
# package      DE_EPAGES::Presentation::Hooks::Servlet
# state        public
# description  Additional hook function for OnIsEp6HandledUnityRequest hook.
#========================================================================================
package DE_EPAGES::Presentation::Hooks::Servlet;
use DE_EPAGES::Presentation::API::Constants qw ( UNITY_SF_VIEW_ACTION_PREFIX ); ##no critic(RequireCorrectImports)

use strict;

#========================================================================================
# function     OnIsEp6HandledUnityRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnIsEp6HandledUnityRequest($hParams);
#----------------------------------------------------------------------------------------
# description  Triggered by hook IsEp6HandledUnityRequest.
#               The checkout process should be rendered by epages6 for any Unity shop.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - servlet object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnIsEp6HandledUnityRequest {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Object'};

    # skip if another hook function already acknowledges the request as a unity request handled by epages6
    return if $hParams->{'Values'}->{'IsEp6HandledUnityRequest'};

    my $aChangeActionsHandledByEp6 = [
       'BlockMonitor'
    ];

    my $aViewActionsHandledByEp6 = [
        'JSONLogClientError'
    ];

    my $ChangeAction = $Servlet->params('ChangeAction');
    my $ViewAction = $Servlet->params('ViewAction');

    if (   $ChangeAction ~~ $aChangeActionsHandledByEp6
        || $ViewAction ~~ $aViewActionsHandledByEp6
        || $ViewAction =~ m/^${\UNITY_SF_VIEW_ACTION_PREFIX}/ )
    {
        $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
    }

    return;
}

1;