#========================================================================================
# package      DE_EPAGES::ProductPortal::API::Portal
# state        public
#----------------------------------------------------------------------------------------
# description  This module creates PortalSites
#========================================================================================
package DE_EPAGES::ProductPortal::API::Portal;

use base Exporter;
use strict;

our @EXPORT_OK = qw (
    LoadPortalSite
    GetPortalConfigFolder
);

#========================================================================================
# function     LoadPortalSite
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $PortalSite = LoadPortalSite($Shop, $PortalSiteID);
#----------------------------------------------------------------------------------------
# description  Create a new PortalSite.
#----------------------------------------------------------------------------------------
# input        $Shop | shop | DE_EPAGES::Shop::API::Object::Shop
# input        $PortalSiteID | PortalSite ObjectId  | integer
#----------------------------------------------------------------------------------------
# return       $PortalSite | portal site object | DE_EPAGES::ProductPortal::API::Object::PortalSite
#========================================================================================
sub LoadPortalSite {
    my ($Shop, $PortalSiteID) = @_;

    my $PortalSite = $Shop->loadObject($PortalSiteID, 'Object', { AllowSystemSite => 1 });
    return unless $PortalSite->instanceOf('PortalSite'); # could be a PortalConfig object

    return $PortalSite;
}

#========================================================================================
# function     GetPortalConfigFolder
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $PortalConfigFolder = GetPortalConfigFolder($Shop, $PortalSite);
#----------------------------------------------------------------------------------------
# description  Create a new folder in Shop if not exists and returns the folder.
#----------------------------------------------------------------------------------------
# input        $Shop | shop | DE_EPAGES::Shop::API::Object::Shop
# input        $PortalSite | portal site object | DE_EPAGES::ProductPortal::API::Object::PortalSite
# input        $hInfo | additional attribute values for creating the new object | ref.hash
#----------------------------------------------------------------------------------------
# return       $PortalConfigFolder | the folder object | Object
#========================================================================================
sub GetPortalConfigFolder {
    my ($Shop, $PortalSite, $hInfo) = @_;

    if ( $PortalSite->isDeprecated() ) {
        return;
    }

    my $PortalConfigFolder = $Shop->folder('PortalConfigs', $hInfo);

    if( $PortalConfigFolder->existsChild($PortalSite->alias()) ) {
        return;
    }

    return $PortalConfigFolder;
}

1;
