#========================================================================================
# package      DE_EPAGES::ProductPortal::t::unit::PortalSite
# base         DE_EPAGES::base
#----------------------------------------------------------------------------------------
# description  unit test for API::Object::PortalSite
#========================================================================================
package DE_EPAGES::ProductPortal::t::unit::PortalSite;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Core::API::PerlTools qw (GetCurrentDateTime AddDuration SubtractDuration);
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_isDeprecated();
    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_isDeprecated {
    my $self = shift;
    my $SubTestName = ( caller(0) )[3];

    my $PortalSiteMockObject1 = $self->_loadPortalSite();
    ok(!$PortalSiteMockObject1->isDeprecated(), "$SubTestName - Portal site IS NOT deprecated when there's not deprecation date value.");

    my $DateInTheFuture = AddDuration(GetCurrentDateTime(), 'months', 1);
    my $PortalSiteMockObject2 = $self->_loadPortalSite($DateInTheFuture);
    ok(!$PortalSiteMockObject2->isDeprecated(), "$SubTestName - Portal site IS NOT deprecated for a deprecation date in the future.");

    my $DateInThePast = SubtractDuration(GetCurrentDateTime(), 'months', 1);
    my $PortalSiteMockObject3 = $self->_loadPortalSite($DateInThePast);
    ok($PortalSiteMockObject3->isDeprecated(), "$SubTestName - Portal site IS deprecated for a deprecation date in the past.");
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _loadPortalSite {
    my $self = shift;
    my ($DeprecationDate) = @_;

    my $hParameterList = {
        'DeprecationDate' => $DeprecationDate
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::ProductPortal::API::Object::PortalSite', $hParameterList);

    return $Mockify->getMockObject();
}


__PACKAGE__->runScript();
