#========================================================================================
# package      DE_EPAGES::Shipping::API::Attributes::ShippingMethod_Ext
# state        private
# base         DE_EPAGES::Object::API::BaseAttribute
# description  Attribute interface for ShippingMethod_Ext.
#========================================================================================
package DE_EPAGES::Shipping::API::Attributes::ShippingMethod_Ext;
use base qw( DE_EPAGES::Object::API::BaseAttribute );

use strict;
use DE_EPAGES::Object::API::Factory qw ( LoadObject );
use DE_EPAGES::Shipping::API::Table::ShippingMethodCustomerGroup qw ( InsertShippingMethodCustomerGroup
                                                                    DeleteShippingMethodCustomerGroup
                                                                    GetPKeyShippingMethodCustomerGroupsByShippingMethodID
                                                                    GetInfoShippingMethodCustomerGroupsByShippingMethodID );

#========================================================================================
# function     getAttributes
# state        private
#----------------------------------------------------------------------------------------
# syntax       $hValues = $Package->( $Object, $aNames );
# example      # never call getAttributes directly!
#               $Value = $Object->get( $AttributeName );
#----------------------------------------------------------------------------------------
# description  Returns attribute values of an object.
#               Used by <function DE_EPAGES::Object::Object::Object::get>
#----------------------------------------------------------------------------------------
# input        $Object | object | object
# input        $aNames | list of attribute names | ref.array
# return       $hValues | attribute name => value hash | ref.hash
#========================================================================================
sub getAttributes {
    my $class = shift;
    my ($Object, $aNames) = @_;
    my $hInfo = {};

    foreach my $Name (@$aNames) {
        if ($Name eq 'UsableAtStorefront' ) {
            my $Shop = $Object->getSite();
            my $Usable = 1;
            foreach my $CurrencyID (map {$_->{'CurrencyID'} } grep { $_->{'IsActivated'} == 1 } @{$Shop->get('Currencies')}) {
                $Usable &&= $Object->usableAtStorefront({ 'TaxModel' => $Shop->get('TaxModel'), CurrencyID => $CurrencyID});
                last unless $Usable;
            }
            $hInfo->{$Name} = $Usable;
        }
        elsif ($Name eq 'CustomerGroups' ) {
            $hInfo->{$Name} = [ map { LoadObject($_->{'CustomerGroupID'} ) } @{GetInfoShippingMethodCustomerGroupsByShippingMethodID($Object->id)} ] ;
        }
        elsif ($Name eq 'HasSettings' ) {
            $hInfo->{$Name} = $Object->hasSettings;
        }
    }
    return $hInfo;
}

sub setAttributes {
    shift;
    my ($Object, $hUpdate) = @_;

    foreach my $Name ( keys %$hUpdate ) {
        if ( $Name eq 'CustomerGroups' ) {
            # test the object type of each loop item
            my $aCustomerGroups = $hUpdate->{$Name};

            # delete all loop items
            my $aKeys = GetPKeyShippingMethodCustomerGroupsByShippingMethodID( $Object->id );
            DeleteShippingMethodCustomerGroup( $_ ) foreach @$aKeys;

            #insert new items
            foreach my $CustomerGroup ( @$aCustomerGroups ) {
                InsertShippingMethodCustomerGroup( {
                    ShippingMethodID => $Object->id,
                    CustomerGroupID => $CustomerGroup->id,
                } );
            }
        }
    }
    return;
}

1;
