#REM
  Parameters:
    #SNIPPET.Type ... string - type of address script (e.g. "Address", "Contact", "Customer")
    #SNIPPET.Context ... string - name of context object (e.g. "Shop", "AddressAttributes") (optional)
    #SNIPPET.Prefix ... string -  prefix for selectors (e.g. "BillingAddress", "ShippingAddress") (optional)
    #SNIPPET.Index ... integer - index to identify similar elements (optional)
    #SNIPPET.StateSelection ... string - div element for StateSelection

  Example:
    #FUNCTION("SNIPPET", "SNIPPET-MenuAddressScriptDefault", "Type,Context,Prefix,Index,StateSelection",
        "Customer", "Shop", "BillingAddress","", "ep-#ID#SPACE[0]_State")
    #SNIPPET("SNIPPET-MenuAddressScriptDefault", "Type,Context,Prefix,Index,StateSelection",
        "Customer", "Shop", "BillingAddress", "", "ep-#ID#SPACE[0]_State")
#ENDREM

#LOCAL("Prefix", "")
#LOCAL("Context", "")
#LOCAL("Index", "")
#LOCAL("IsAddressForDefaultTemplate", NOT((#CountryID EQ "840") AND (#Shop.TaxMethod.Alias EQ "TaxUS")) )
    #IF(#DEFINED(#SNIPPET.Prefix) )
        #SET("Prefix", #SNIPPET.Prefix)
    #ENDIF

    if(snippetAddressPrefixJS === undefined) {
        var snippetAddressPrefixJS = "";
    }

    snippetAddressPrefixJS = "#Prefix".replace(/\./g, "\\.");

    #IF(#DEFINED(#SNIPPET.Context) AND #SNIPPET.Context NE "")
        #SET("Context", #SNIPPET.Context.".")
    #ENDIF

    #IF(#DEFINED(#SNIPPET.Index))
        #SET("Index", #SNIPPET.Index)
    #ENDIF

    countries.default = {
        #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
            template: '#ShopWizardSteps-Contact-Tmpl-Default',
        #ELSE
            template: "#Menu-" + snippetAddressPrefixJS + "AddressTmpl-Default",
        #ENDIF

        address: {
            #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Address,Contact")
                street: {
                    #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                        selector: '#' + 'Street#Index',
                    #ELSE
                        selector: 'input[name="#Prefix#SPACE[0]Street"]',
                    #ENDIF
                    value: '#IF(#IsAddressForDefaultTemplate)#GET(#Context."Street")#ENDIF'
                },
            #ENDIF
            #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Address")
                street2: {
                    selector: 'input[name="#Prefix#SPACE[0]Street2"]',
                    value: '#IF(#IsAddressForDefaultTemplate)#Street2#ENDIF'
                },
            #ENDIF
            country: {
                #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                    selector: '#' + 'CountryID#Index',
                #ELSE
                    selector: 'select[name="#Prefix#SPACE[0]CountryID"]',
                #ENDIF
                value: '#IF(#IsAddressForDefaultTemplate)#GET(#Context."CountryID")#ENDIF'
            },
            zip: {
                #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                    selector: '#' + 'Zipcode#Index',
                #ELSE
                    selector: 'input[name="#Prefix#SPACE[0]Zipcode"]',
                #ENDIF
                value: '#IF(#IsAddressForDefaultTemplate)#GET(#Context."Zipcode")#ENDIF'
            },
            city: {
                #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                    selector: '#' + 'City#Index',
                #ELSE
                    selector: 'input[name="#Prefix#SPACE[0]City"]',
                #ENDIF
                value: '#IF(#IsAddressForDefaultTemplate)#GET(#Context."City")#ENDIF'
            },
            state: {
                #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                    selector: '#' + 'State#Index',
                #ELSE
                    selector: 'input[name="#Prefix#SPACE[0]State"]',
                #ENDIF
                value: '#IF(#IsAddressForDefaultTemplate)#GET(#Context."State")#ENDIF'
            }
        },
        onAfterRender: function(address) {
        $('#' + snippetAddressPrefixJS + "#SNIPPET.StateSelection").presentationUiStateselection(#BLOCK("NewLineReplace","") {
            "input": {
                    "name": "#Prefix#SPACE[0]State",
                    "id": #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Customer,Contact") snippetAddressPrefixJS + "State#Index" #ELSE "" #ENDIF,
                    "mandatoryStar": "ep-mandatory",
                    "label": "{State}",
                    "emptyEntry": "{EmptyEntry}"
                },
                "countrySelectId": #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Address")"ep-#ID#SPACE[0]_CountryID"#ELSE snippetAddressPrefixJS + "CountryID#Index"#ENDIF,
                "cssClasses":{
                    #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Customer")
                        "inputField": "ep-InputField",
                        "inputLabelling": "InputLabelling",
                        "select": "FullSize",
                        "input": "Text",
                    #ELSIF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact")
                        "inputField": "InputField",
                        "inputLabelling": "ep-State#Index",
                    #ELSE
                        "inputField": "InputField",
                        "inputLabelling": "ep-stateselection-statelabel",
                        "select": "LongText",
                        "input": "Text",
                    #ENDIF
                    "dialogError": "DialogError"
                },
                #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Customer")
                    "countryId": #LOCAL("CountryID", #CountryID)"#CountryID"#ENDLOCAL,
                    "preselectedState": ep('input[type=hidden][name="'+ snippetAddressPrefixJS +'State"]').val(),
                #ELSE
                    "countryId": address.country.value,
                    "preselectedState": address.state.value,
                #ENDIF
                "shopAddressCountryId": "",
                "formError":#IF(#GET("FormError_"."State"))true#ELSE#SPACE[0]false#ENDIF,
                "shopRegistrationField": {
                    #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Customer")
                        "state": {
                            "isVisibleName": #IF(#GET("Shop.RegistrationField.State.Is".#Element."Visible")) true #ELSE false #ENDIF,
                            "isMandatoryName": #IF(#GET("Shop.RegistrationField.State.Is".#Element."Mandatory")) true #ELSE false #ENDIF
                        },
                        "countryId": {
                            "isVisibleName": #IF(#GET("Shop.RegistrationField.CountryID.Is".#Element."Visible")) true #ELSE false #ENDIF,
                            "isMandatoryName": #IF(#GET("Shop.RegistrationField.State.Is".#Element."Mandatory")) true #ELSE false #ENDIF
                        }
                    #ELSE
                         "state": {
                            "isVisibleName": #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Contact") false #ELSE true #ENDIF,
                            "isMandatoryName": false
                        },
                        "countryId": {
                            "isVisibleName": true,
                            "isMandatoryName": true
                }
                    #ENDIF
                },
                "data":{
                  #JOIN(",", #Shop.ShopCountries)"#CountryID": {
                    "subdivsMandatory": #IF(#SubdivsMandatory)true#ELSE#SPACE[0]false#ENDIF,
                    "subDivisions": [
                      #JOIN(",",#SORT(#SubDivisions, "English")){
                        "code": "#Code",
                        "language": {
                          "english": "#English",
                          "native": "#Native"
                        }
                      }#ENDJOIN
                    ]
                  }#ENDJOIN
                }
        }#ENDBLOCK);
    },
    onChange: function() {
        #IF(#DEFINED(#SNIPPET.Type) AND #SNIPPET.Type IN "Customer,Contact")
            $( '#' + snippetAddressPrefixJS + "CountryID#Index").trigger('change.presentationUiStateselection');
        #ELSE
             $("#" + "ep-#ID#SPACE[0]_CountryID").trigger('change.presentationUiStateselection');
        #ENDIF
    }
};
#ENDLOCAL #REM /* IsAddressForDefaultTemplate */ #ENDREM
#ENDLOCAL #REM /* Context */ #ENDREM
#ENDLOCAL #REM /* Index */ #ENDREM
#ENDLOCAL #REM /* Prefix */ #ENDREM
