#========================================================================================
# package      DE_EPAGES::UniversalPortal::API::UniversalPortal
# state        public
#----------------------------------------------------------------------------------------
# description  This module creates and deletes UniversalPortalSites
#========================================================================================
package DE_EPAGES::UniversalPortal::API::UniversalPortal;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::Core::API::TestParameter qw ( TestObject TestString );

use base Exporter;
use strict;

our @EXPORT_OK = qw (
  CreateUniversalPortalSite
  DeleteUniversalPortalSite
);

#========================================================================================
# function     CreateUniversalPortalSite
# state        public
#----------------------------------------------------------------------------------------
# syntax       CreateUniversalPortalSite( $Shop, $hValues );
#----------------------------------------------------------------------------------------
# description  Create a new UniversalPortalSite.
#----------------------------------------------------------------------------------------
# input        $Shop | shop | DE_EPAGES::Shop::API::Object::Shop
# input        $hValues | Stores Values like, Alias, LocaleID, Portal  | ref.hash
#----------------------------------------------------------------------------------------
# return       $PortalSite | portal site object | DE_EPAGES::UniversalPortal::API::Object::UniversalPortalSite
#========================================================================================
sub CreateUniversalPortalSite {
    my ( $Shop, $hValues ) = @_;

    TestObject ( 'Shop', $Shop, 'DE_EPAGES::Shop::API::Object::Shop' );
    TestString ( $_, $hValues->{$_} ) foreach qw ( Alias LocaleID );
    TestObject ( 'Portal', $hValues->{'Portal'}, 'DE_EPAGES::ProductPortal::API::Object::Portal' );
    my $Folder = $Shop->folder('UniversalPortalSites');

    Error('OBJECT_EXISTS') if ($Folder->existsChild($hValues->{'Alias'}));
    return $Folder->insertChild( 'UniversalPortalSite', $hValues);
}

#========================================================================================
# function     DeleteUniversalPortalSite
# state        public
#----------------------------------------------------------------------------------------
# syntax       DeleteUniversalPortalSite( $Shop, $PortalSiteAlias );
#----------------------------------------------------------------------------------------
# description  Deletes a portalsite
#----------------------------------------------------------------------------------------
# input        $Shop | shop | DE_EPAGES::Shop::API::Object::Shop
# input        $PortalSiteAlias | Alias | string
#========================================================================================
sub DeleteUniversalPortalSite {
    my ( $Shop, $PortalSiteAlias ) = @_;
    TestObject( 'Shop', $Shop, 'DE_EPAGES::Shop::API::Object::Shop' );
    TestString( 'PortalSiteAlias', $PortalSiteAlias );

    my $PortalSiteObject = $Shop->child('UniversalPortalSites')->child($PortalSiteAlias);
    $PortalSiteObject->delete;
    return;
}

1;
