#========================================================================================
# package      DE_EPAGES::UniversalPortal::UI::UniversalPortal
# state        private
#========================================================================================
package DE_EPAGES::UniversalPortal::UI::UniversalPortal;
use base DE_EPAGES::Presentation::UI::Object;
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject Transaction );
use DE_EPAGES::UniversalPortal::API::UniversalPortal qw ( CreateUniversalPortalSite );
use DE_EPAGES::ProductPortal::API::Portal qw ( GetPortalConfigFolder );
use DE_EPAGES::Core::API::TestParameter qw ( TestObject );

use strict;

sub CreatePortalConfig {

    #fetch Name from Textfield
    my $self            = shift;
    my ($Servlet)       = @_;
    my $Shop            = $Servlet->object();
    my $hNewPortalSite  = $Servlet->form()->form( $Shop, 'NewPortalSite' );
    my $UniversalPortal = $self->_getUniversalPortal($Shop->get('IsUnityRegistered'));

    $hNewPortalSite->{'Portal'} = $UniversalPortal;
    $hNewPortalSite->{'Alias'} = $hNewPortalSite->{'Alias'}.'_'.$hNewPortalSite->{'LocaleID'};

    $self->_createUniversalPortalConfig($Servlet, $Shop, $hNewPortalSite);

    $Servlet->form->executeFormError();
    return;
}

sub _createUniversalPortalConfig {
    my $self = shift;
    my ($Servlet, $Shop, $hNewPortalSite) = @_;

    eval {
        Transaction(
            sub {
                my $UniversalPortalSite = CreateUniversalPortalSite( $Shop, $hNewPortalSite );
                TestObject ( 'UniversalPortalSite', $UniversalPortalSite, 'DE_EPAGES::UniversalPortal::API::Object::UniversalPortalSite' );

                my $UniversalConfigFolder = GetPortalConfigFolder( $Shop, $UniversalPortalSite );
                TestObject ( 'UniversalConfigFolder', $UniversalConfigFolder, 'DE_EPAGES::Object::API::Object::Object' );

                my $SystemPortal = $UniversalPortalSite->get('Portal');
                my $Class = $SystemPortal->get('PortalConfigClass');

                $self->_createNewObject($Servlet, $UniversalConfigFolder, $Class, {
                    'Alias'      => $UniversalPortalSite->alias(),
                    'PortalSite' => $UniversalPortalSite,
                });
            }
        );
    };
    if ( ExistsError() ) {
        my $Error = GetError();
        $Servlet->form->mapFormError( {
                'Form'    => 'CreatePortalConfig',
                'Name'    => 'CreatePortalConfig',
                'Message' => $Error->shortMessage,
            },
            $Error
        );
    }
    return;
}

sub _createNewObject {
    my $self = shift;
    my ($Servlet, $UniversalConfigFolder, $Class, $hParams) = @_;

    return $self->NewObject($Servlet, $UniversalConfigFolder, $Class, $hParams);
}

sub _getUniversalPortal {
    my $self = shift;
    my ($IsUnityRegistered) = @_;

    if ($IsUnityRegistered) {
        return LoadRootObject()->folder('Portals')->child('UniversalUnity');
    }
    return LoadRootObject()->folder('Portals')->child('Universal');
}

1;