#========================================================================================
# package      DE_EPAGES::ProductPortal::t::unit::UI_ProductPortal
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for UI::ProductPortal
#========================================================================================
package DE_EPAGES::UniversalPortal::t::unit::UI_UniversalPortal;
use base DE_EPAGES::Test::API::UnitTest::Test;

use Test::Mockify::Matcher qw ( Any HashRef Object String );
use DE_EPAGES::Test::Mock::Mockify qw ( GetCallCount GetParametersFromMockifyCall );
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Mockify::Sut;
use Test::MockObject;
use Test::More;
use Test::Exception;

use strict;

use constant PORTAL_SITE_ID => '1222';
use constant PORTAL_CONFIG_ID => '1234';
use constant PORTAL_ALIAS => 'Portal1';
use constant PORTAL_LOCALEID => 'de_DE';

sub test {
    my $self = shift;

    $self->test_CreatePortalConfig_Successful();
    $self->test_CreatePortalConfig_UniversalPortalSite_NotCreated();

    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_CreatePortalConfig_Successful {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hParams = {
        'IsPortalSiteDeprecated'    => 0,
        'AddPortalConfig'           => 1,
        'DeletePortalConfig'        => 0,
        'IsUnityRegistered'         => 1,
        'IsUniversalPortalSiteFail' => 0
    };

    $hParams->{'PortalConfigFolder'} = $self->_createPortalConfigFolder($hParams);
    $hParams->{'UniversalPortalSite'} = $self->_createUniversalPortalSite($hParams);

    my $Servlet = $self->_createServlet($hParams);

    my $SUT = $self->_createSUT($hParams);

    lives_ok(sub { $SUT->CreatePortalConfig($Servlet) } , $SubTestName.' - no error with CreatePortalConfig');
    is(GetCallCount($SUT, '_createUniversalPortalConfig'), 1,
        "$SubTestName - Portal config creation method _createUniversalPortalConfig DOES gets called.");
    is(GetCallCount($SUT, 'Transaction'), 1, "$SubTestName - Transaction method DOES gets called.");
    is(GetCallCount($SUT, '_createNewObject'), 1, "$SubTestName - _createNewObject method DOES gets called.");

    my $aGotMethodParams = GetParametersFromMockifyCall($SUT,'_createUniversalPortalConfig');
    is($aGotMethodParams->[2]->{'Portal'}->get('PortalType'), 'UniversalUnity', "$SubTestName - _createUniversalPortalConfig PortalType is UniversalUnity.");
    is_deeply($aGotMethodParams->[0], $Servlet, "$SubTestName - Servlet Parameter in _createUniversalPortalConfig is correct.");
    is_deeply($aGotMethodParams->[1], $Servlet->object(), "$SubTestName - Shop Parameter in _createUniversalPortalConfig is correct.");

    my $aGotNewObjectParams = GetParametersFromMockifyCall($SUT,'_createNewObject');
    is_deeply($aGotNewObjectParams->[0], $Servlet, "$SubTestName - Servlet Parameter in _createNewObject is correct.");
    is_deeply($aGotNewObjectParams->[1], $hParams->{'PortalConfigFolder'}, "$SubTestName - PortalConfigFolder Parameter in _createNewObject is correct.");
    is($aGotNewObjectParams->[2], 'PortalConfigClass', "$SubTestName - Class Parameter in _createNewObject is correct.");

    my $hExpectedParams = {
        'Alias' => $hParams->{'UniversalPortalSite'}->alias(),
        'PortalSite' => $hParams->{'UniversalPortalSite'}
    };
    is_deeply($aGotNewObjectParams->[3], $hExpectedParams, "$SubTestName - HashRef Parameter is correct.");

}

sub test_CreatePortalConfig_UniversalPortalSite_NotCreated {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hParams = {
        'IsPortalSiteDeprecated'    => 0,
        'AddPortalConfig'           => 1,
        'DeletePortalConfig'        => 0,
        'IsUnityRegistered'         => 0,
        'IsUniversalPortalSiteFail' => 1,
    };

    $hParams->{'PortalConfigFolder'} = $self->_createPortalConfigFolder($hParams);
    $hParams->{'UniversalPortalSite'} = $self->_createUniversalPortalSite($hParams);

    my $Servlet = $self->_createServlet($hParams);

    my $SUT = $self->_createSUT($hParams);

    throws_ok(sub { $SUT->CreatePortalConfig($Servlet) }, qr/the input field CreatePortalConfig is not correct/, "$SubTestName - IsUniversalPortalSiteFail exception caught okay.");
    is(GetCallCount($SUT, '_createUniversalPortalConfig'), 1,
        "$SubTestName - Portal config creation method _createUniversalPortalConfig DOES gets called.");
    is(GetCallCount($SUT, 'Transaction'), 1, "$SubTestName - Transaction method DOES gets called.");
    is(GetCallCount($SUT, '_createNewObject'), 0, "$SubTestName - _createNewObject method does NOT gets called.");

    my $aGotMethodParams = GetParametersFromMockifyCall($SUT,'_createUniversalPortalConfig');
    is($aGotMethodParams->[2]->{'Portal'}->get('PortalType'), 'Universal', "$SubTestName - PortalType is Universal.");
}


#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hParams) = @_;

    my $aParameterList = [];
    my $Mockify = Test::Mockify::Sut->new( 'DE_EPAGES::UniversalPortal::UI::UniversalPortal', $aParameterList );

    $Mockify->spy('_createUniversalPortalConfig')
        ->when(
            Object('DE_EPAGES::Presentation::Servlet::Permission'),
            Object('DE_EPAGES::Shop::API::Object::Shop'),
            HashRef());


    my $Child = Test::MockObject->new();

    $Child->mock( 'child',
        sub {
            my $class = shift;
            my ($Param) = @_;

            if ($Param eq 'UniversalUnity' || $Param eq 'Universal') {
                $hParams->{'PortalType'} = $Param;
                return $self->_createPortal($hParams);
            }
            return;
        }
    );

    my $Folder = Test::MockObject->new();
    $Folder->mock( 'folder',
        sub {
            my $self = shift;
            my ($Param) = @_;

            if ($Param eq 'Portals') {
                return $Child;
            }
            return;
        }
    );
    
    
    $Mockify->mockImported('DE_EPAGES::Object::API::Factory', 'LoadRootObject')
        ->when()
        ->thenReturn($Folder);
        
    $Mockify->mockImported('DE_EPAGES::Object::API::Factory', 'Transaction')
        ->when(Any())
        ->thenCall(sub{ return $_[0]();});

    $Mockify->mockImported('DE_EPAGES::UniversalPortal::API::UniversalPortal', 'CreateUniversalPortalSite')
        ->when(Object('DE_EPAGES::Shop::API::Object::Shop'),HashRef())
        ->thenReturn($hParams->{'UniversalPortalSite'});

   $Mockify->mockImported('DE_EPAGES::ProductPortal::API::Portal', 'GetPortalConfigFolder')
       ->when(Object('DE_EPAGES::Shop::API::Object::Shop'), Object('DE_EPAGES::UniversalPortal::API::Object::UniversalPortalSite'))
       ->thenReturn($hParams->{'PortalConfigFolder'});

    $Mockify->mock('_createNewObject')->when(Object(), Object(), String(), HashRef())->thenReturnUndef();

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createServlet {
    my $self = shift;
    my ($hParams) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyServlet->new( $self->_createShop($hParams));

    $Mockify->mock('form', $self->_createForm() );

    return $Mockify->getMockObject();

}

#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ($hParams) = @_;


    my $hAttributes = {
        'Alias' => 'MyShop',
        'IsUnityRegistered' => $hParams->{'IsUnityRegistered'},
        'PortalConfigs' => undef
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop',$hAttributes);

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createPortalConfigFolder {
    my $self = shift;

    my $MockifyObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Object',{});

    $MockifyObject->addMockWithReturnValueAndParameterCheck('existsChild', 0, [ 'string' ]);

    return $MockifyObject->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createForm {
    my $self = shift;
    my ($hParams) = @_;

    my $aParameterList = [];
    my $Mockify = Test::Mockify->new(
                   'DE_EPAGES::Presentation::API::Form',
                   $aParameterList
    );

    $aParameterList = [];
    $Mockify->mock('form')
        ->when(
            Object('DE_EPAGES::Shop::API::Object::Shop'),
            String('NewPortalSite'))
        ->thenReturn(
            {'Alias' => PORTAL_ALIAS, 'LocaleID' => PORTAL_LOCALEID}
    );

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createUniversalPortalSite {
    my $self = shift;
    my ($hParams) = @_;

    if($hParams->{'IsUniversalPortalSiteFail'}) {
        return 'NOT AN OBJECT';
    }

    my $hAttributes = {
        'ID' => PORTAL_SITE_ID,
        'Alias' => PORTAL_ALIAS,
        'DeprecationDate' => undef,
        'instanceOf' => 'PortalSite',
        'LocaleID' => PORTAL_LOCALEID,
        'Portal' => $self->_createPortal(),
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::UniversalPortal::API::Object::UniversalPortalSite',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createPortal {
    my $self = shift;
    my ($hParams) = @_;

    my $hAttributes = {
        'Alias' => PORTAL_ALIAS . '_' . PORTAL_LOCALEID,
        'PortalConfigClass' => 'PortalConfigClass',
        'PortalType'        => $hParams->{'PortalType'},
    };

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::ProductPortal::API::Object::Portal',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();