#========================================================================================
# package      DE_EPAGES::UniversalPortal::t::unit::UniversalPortal
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for API::UniversalPortal
#========================================================================================
package DE_EPAGES::UniversalPortal::t::unit::UniversalPortal;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Mockify::Sut;
use Test::MockObject;
use Test::More;
use Test::Exception;

use DE_EPAGES::UniversalPortal::API::UniversalPortal qw ( CreateUniversalPortalSite );

use strict;

use constant PORTAL_SITE_ID => '1222';
use constant PORTAL_CONFIG_ID => '1234';
use constant PORTAL_ALIAS => 'Portal1';
use constant PORTAL_LOCALEID => 'de_DE';

sub test {
    my $self = shift;

    $self->test_CreateUniversalPortalSite();
    $self->test_CreateUniversalPortalSite_ObjectExistsError();

    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_CreateUniversalPortalSite {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hParams = {
        'IsPortalSiteDeprecated'    => 0,
        'AddPortalConfig'           => 1,
        'DeletePortalConfig'        => 0,
        'IsUnityRegistered'         => 1,
        'IsUniversalPortalSiteFail' => 0,
        'IsDuplicatedChild'         => 0,
    };

    $hParams->{'UniversalPortalSite'} = $self->_createUniversalPortalSite($hParams);

    my $Shop = $self->_createShop($hParams);
    my $Portal = $self->_createPortal();

    my $hValues = {
        'Portal'   => $Portal,
        'Alias'    => PORTAL_ALIAS,
        'LocaleID' => PORTAL_LOCALEID
    };

    lives_ok(sub { CreateUniversalPortalSite($Shop, $hValues) } , $SubTestName.' - no error with CreateUniversalPortalSite');
    my $ResultObject = CreateUniversalPortalSite($Shop, $hValues);

    is_deeply($ResultObject, $hParams->{'UniversalPortalSite'}, "$SubTestName - UniversalPortalSite ok.")

}

#----------------------------------------------------------------------------------------
sub test_CreateUniversalPortalSite_ObjectExistsError {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $hParams = {
        'IsPortalSiteDeprecated'    => 0,
        'AddPortalConfig'           => 1,
        'DeletePortalConfig'        => 0,
        'IsUnityRegistered'         => 1,
        'IsUniversalPortalSiteFail' => 0,
        'IsDuplicatedChild'         => 1,
    };

    $hParams->{'UniversalPortalSite'} = $self->_createUniversalPortalSite($hParams);

    my $Shop = $self->_createShop($hParams);
    my $Portal = $self->_createPortal();

    my $hValues = {
        'Portal'   => $Portal,
        'Alias'    => PORTAL_ALIAS,
        'LocaleID' => PORTAL_LOCALEID
    };

    throws_ok(sub { CreateUniversalPortalSite($Shop, $hValues) }, qr/OBJECT_EXISTS/, "$SubTestName - existsChild OBJECT_EXISTS exception caught okay.");
    
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------

sub _createShop {
    my $self = shift;
    my ($hParams) = @_;


    my $hAttributes = {
        'Alias' => 'MyShop',
        'IsUnityRegistered' => $hParams->{'IsUnityRegistered'},
        'PortalConfigs' => undef
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop',$hAttributes);
    my $aParameterTypes = [ 'int', {'string' => 'Object'}, 'hashref' ];

    $aParameterTypes = [ {'string' => 'PortalConfigs'}, 'hashref' ];
    $Mockify->addMock('folder',
        sub {
            my $class = shift;
            my ($param1) = @_;

            if ($param1 eq 'UniversalPortalSites') {
                return $self->_createFolderObject($hParams);
            }
            return;

        });

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createFolderObject {
    my $self = shift;
    my ($hParams) = @_;

    my $MockifyObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Object',{});

    $MockifyObject->addMockWithReturnValueAndParameterCheck('existsChild', $hParams->{'IsDuplicatedChild'}, [ {'string' => PORTAL_ALIAS} ]);

    $MockifyObject->addMockWithReturnValueAndParameterCheck(
        'insertChild',
        $hParams->{'UniversalPortalSite'},
        [
            {'string' => 'UniversalPortalSite'},
            'hashref'
        ]
    );

    return $MockifyObject->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createUniversalPortalSite {
    my $self = shift;
    my ($hParams) = @_;

    my $hAttributes = {
        'ID' => PORTAL_SITE_ID,
        'Alias' => PORTAL_ALIAS,
        'DeprecationDate' => undef,
        'instanceOf' => 'PortalSite',
        'LocaleID' => PORTAL_LOCALEID,
        'Portal' => $self->_createPortal(),
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::UniversalPortal::API::Object::UniversalPortalSite',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createPortal {
    my $self = shift;

    my $hAttributes = {
        'PortalConfigClass' => 'PortalConfigClass'
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::ProductPortal::API::Object::Portal',
        $hAttributes
    );

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();